summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIvan Kanakarakis <ivan.kanak@gmail.com>2020-06-02 23:36:38 +0300
committerIvan Kanakarakis <ivan.kanak@gmail.com>2020-06-02 23:45:08 +0300
commit71404900728223e8fa26cd37de212dd08d919f6b (patch)
tree0ebbcf1cf1965b59e5be8f058703e74b7282e463
parentbb01758480be04f8a8083310dca0f7d2bf8b5547 (diff)
downloadpysaml2-71404900728223e8fa26cd37de212dd08d919f6b.tar.gz
Fix param documentation
Signed-off-by: Ivan Kanakarakis <ivan.kanak@gmail.com>
-rw-r--r--src/saml2/client_base.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/saml2/client_base.py b/src/saml2/client_base.py
index 15786dae..f38d1c0d 100644
--- a/src/saml2/client_base.py
+++ b/src/saml2/client_base.py
@@ -252,9 +252,11 @@ class Base(Entity):
:param allow_create: If the identity provider is allowed, in the course
of fulfilling the request, to create a new identifier to represent
the principal.
- :param requested_attributes: A list of dicts which contain attributes
- to be appended to the requested_attributes config option. The
- dicts format is similar to the requested_attributes config option.
+ :param requested_attributes: A list of dicts which define attributes to
+ be used as eIDAS Requested Attributes for this request. If not
+ defined the configuration option requested_attributes will be used,
+ if defined. The format is the same as the requested_attributes
+ configuration option.
:param kwargs: Extra key word arguments
:return: either a tuple of request ID and <samlp:AuthnRequest> instance
or a tuple of request ID and str when sign is set to True